"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DynamoDbBootstrapData = void 0;
const aws_iam_1 = require("aws-cdk-lib/aws-iam");
const custom_resources_1 = require("aws-cdk-lib/custom-resources");
const constructs_1 = require("constructs");
const batchAddItems = (scope, table, items) => {
    const policyStatement = new aws_iam_1.PolicyStatement({
        effect: aws_iam_1.Effect.ALLOW,
        actions: ['dynamodb:batchWriteItem'],
        resources: [table.tableArn]
    });
    const policy = custom_resources_1.AwsCustomResourcePolicy.fromStatements([policyStatement]);
    const batchCount = Math.ceil(items.length / 25);
    for (let i = 0; i < batchCount; i++) {
        const batchItems = [];
        while (batchItems.length < 26 && items.length > 0) {
            batchItems.push({
                PutRequest: {
                    Item: items.shift()
                }
            });
        }
        const intializationData = {
            service: 'DynamoDB',
            action: 'batchWriteItem',
            physicalResourceId: custom_resources_1.PhysicalResourceId.of(`${table.tableName}-bootstrap-${i}`),
            parameters: {
                "RequestItems": { [table.tableName]: batchItems }
            }
        };
        new custom_resources_1.AwsCustomResource(scope, `DynamoBootstrap_${i}`, {
            onUpdate: intializationData,
            onCreate: intializationData,
            policy
        });
    }
};
class DynamoDbBootstrapData extends constructs_1.Construct {
    constructor(scope, id, { table, bootstrapData }) {
        super(scope, id);
        batchAddItems(this, table, bootstrapData);
        this.node.addDependency(table);
    }
}
exports.DynamoDbBootstrapData = DynamoDbBootstrapData;
//# sourceMappingURL=DynamoDbBootstrapData.js.map